Module: IncludeWithRespect::ModuleWithRespect::ClassMethods

Defined in:
lib/include_with_respect/module_with_respect.rb

Instance Method Summary collapse

Instance Method Details

#extend(module1, *smth) ⇒ Object

Define a new version of extend, which ultimately calls the original extend as extend_without_respect



37
38
39
# File 'lib/include_with_respect/module_with_respect.rb', line 37

def extend(module1, *smth)
  IncludeWithRespect.extend_with_respect(self, module1, *smth)
end

#include(module1, *smth) ⇒ Object

Define a new version of include, which ultimately calls the original include as include_without_respect



31
32
33
# File 'lib/include_with_respect/module_with_respect.rb', line 31

def include(module1, *smth)
  IncludeWithRespect.include_with_respect(self, module1, *smth)
end